from amilib.file_lib import FileLib
from amilib.util import Util
from test.test_all import AmiAnyTest

logger = Util.get_logger(__name__)
class AmiBibliographyTest(AmiAnyTest):
    """

    """
    @classmethod
    def convert_csv_to_bib(cls):
        """

        """